<?php


namespace FiloBlu\ExtProductAalert\View;


use Magento\Framework\App\ObjectManager;
use Magento\Framework\Config\ViewFactory;
use Magento\Framework\View\Asset\Repository;
use Magento\Framework\View\Design\Theme\ThemeProviderInterface;
use Magento\Framework\View\DesignInterface;

class Config extends \Magento\Framework\View\Config
{

    /**
     * List of view configuration objects per theme
     *
     * @var array
     */
    protected $viewConfigs = [];

    /**
     * View service
     *
     * @var \Magento\Framework\View\Asset\Repository
     */
    protected $assetRepo;

    /**
     * File view factory
     *
     * @var \Magento\Framework\Config\ViewFactory
     */
    protected $viewConfigFactory;

    /**
     * @var \Magento\Framework\View\DesignInterface
     */
    private $design;

    private $themeProvider;

    /**
     * Config constructor.
     * @param Repository $assetRepo
     * @param ViewFactory $viewConfigFactory
     * @param DesignInterface $design
     */
    public function __construct(
        Repository $assetRepo,
        ViewFactory $viewConfigFactory,
        DesignInterface $design
    ) {
        $this->assetRepo = $assetRepo;
        $this->viewConfigFactory = $viewConfigFactory;
        $this->design = $design;
    }

    /**
     * Render view config object for current package and theme
     *
     * @param array $params
     * @return \Magento\Framework\Config\View
     */
    public function getViewConfig(array $params = [])
    {
        $this->assetRepo->updateDesignParams($params);
        $viewConfigParams = [];

        /*
         * Load correct themeModel
         */
        $area = $params['area'];
        if ($area == 'frontend') {
            if (strstr($params['themeModel']->getCode(), 'backend')) {
                $themeId = $this->design->getConfigurationDesignTheme($area);
                $params['themeModel'] = $this->getThemeProvider()->getThemeById($themeId);
            }
        }

        if (isset($params['themeModel'])) {
            /** @var \Magento\Framework\View\Design\ThemeInterface $currentTheme */
            $currentTheme = $params['themeModel'];
            $key = $currentTheme->getFullPath();
            if (isset($this->viewConfigs[$key])) {
                return $this->viewConfigs[$key];
            }
            $viewConfigParams['themeModel'] = $currentTheme;
        }
        $viewConfigParams['area'] = (isset($params['area'])) ? $params['area'] : null;

        /** @var \Magento\Framework\Config\View $config */
        $config = $this->viewConfigFactory->create($viewConfigParams);

        if (isset($key)) {
            $this->viewConfigs[$key] = $config;
        }
        return $config;
    }

    /**
     * @return ThemeProviderInterface
     * @deprecated
     */
    private function getThemeProvider()
    {
        if (null === $this->themeProvider) {
            $this->themeProvider = ObjectManager::getInstance()->get(ThemeProviderInterface::class);
        }

        return $this->themeProvider;
    }
}